import { TestBed } from '@angular/core/testing';
import { By } from '@angular/platform-browser';
export class ConfiguredTestComp {
    constructor(component) {
        this.component = component;
        this.config = {
            declarations: [],
            imports: [],
            providers: [],
            schemas: [],
        };
        this.config.declarations = [this.component];
    }
    configure(extraConfig) {
        Object.keys(this.config)
            .filter((property) => extraConfig.hasOwnProperty(property))
            .forEach(property => (this.config[property] = [...this.config[property], ...extraConfig[property]]));
    }
    updateFixture() {
        this.fixture.detectChanges();
    }
    query(element) {
        return this.element.querySelector(element);
    }
    queryAll(cssSelector) {
        const result = this.fixture.debugElement.queryAll(By.css(cssSelector));
        return result;
    }
    setProps(properties) {
        Object.entries(properties).forEach(([key, value]) => {
            this.instance[key] = value;
        });
        this.updateFixture();
    }
    spyOn(methodReference) {
        spyOn(this.instance, methodReference);
        return this.instance[methodReference];
    }
    triggerEvent(selector, eventType, value) {
        const targetElem = this.query(selector);
        if (eventType === "keydown" || eventType === "keyup") {
            targetElem.dispatchEvent(new KeyboardEvent(eventType, { code: value }));
        }
        else if (value) {
            targetElem.value = value;
            targetElem.dispatchEvent(new Event(eventType));
        }
        else {
            targetElem.dispatchEvent(new Event(eventType));
        }
        this.updateFixture();
    }
    compileComponents() {
        TestBed.configureTestingModule(this.config).compileComponents();
    }
}
//# sourceMappingURL=base.js.map